# 📁 documents/

This folder contains metadata about documentation files per service, such as user guides or API references. Each file describes a single document variant for a specific cloud environment.

## 🔧 Example: `ecs-umn.yaml`

```yaml
---
hc_location: usermanual/ecs
html_location: docs/ecs/umn
link: /elastic-cloud-server/umn/
rst_location: umn/source
service_type: ecs
title: User Guide
type: umn
cloud_environments:
  - name: eu_de
    visibility: public
    pdf_visibility: public
    pdf_enabled: true
  - name: swiss
    visibility: public
    pdf_visibility: public
    pdf_enabled: true
```

## 🔧 Example: `ecs-api-ref.yaml`

```yaml
---
hc_location: api/ecs
html_location: docs/ecs/api-ref
link: /elastic-cloud-server/api-ref/
rst_location: api-ref/source
service_type: ecs
title: API Reference
type: api-ref
cloud_environments:
  - name: eu_de
    visibility: public
    pdf_visibility: public
    pdf_enabled: true
  - name: swiss
    visibility: public
    pdf_visibility: public
    pdf_enabled: true
```

## Parameter Reference

| Field                | Type   | Description                                              |
| -------------------- | ------ | -------------------------------------------------------- |
| `hc_location`        | string | Path used in the Horizon Console.                        |
| `html_location`      | string | Location of the built HTML output.                       |
| `link`               | string | Target URL segment for this document.                    |
| `rst_location`       | string | Source folder for `.rst` input.                          |
| `service_type`       | string | Related service identifier (matches `services/`).        |
| `title`              | string | Display name of the document.                            |
| `type`               | string | Document type (e.g., `umn`, `api-ref`, etc.).            |
| `cloud_environments` | list   | Region-specific metadata like visibility or PDF support. |

### `cloud_environments` Options:

| Field            | Type    | Allowed Values                 | Description                        |
| ---------------- | ------- | ------------------------------ | ---------------------------------- |
| `name`           | string  | e.g., `eu_de`, `swiss`         | Name of the cloud region.          |
| `visibility`     | string  | `public`, `internal`, `hidden` | Document visibility level.         |
| `pdf_visibility` | string  | `public`, `internal`, `hidden` | PDF visibility level               |
| `pdf_enabled`    | boolean | `true`, `false`                | Enable PDF export                  |
