# 📁 repositories/

Defines the documentation repositories associated with each service for both internal and public environments. Used for resolving documentation sources and CI sync jobs.

## 🔧 Example: `ecs.yaml`

```yaml
---
service_type: ecs
repositories:
  - environment: public
    repo: opentelekomcloud-docs/elastic-cloud-server
    type: github
    cloud_environments:
      - eu_de
  - environment: internal
    repo: docs/elastic-cloud-server
    type: gitea
    cloud_environments:
      - eu_de
  - environment: public
    repo: opentelekomcloud-docs-swiss/elastic-cloud-server
    type: github
    cloud_environments:
      - swiss
  - environment: internal
    repo: docs-swiss/elastic-cloud-server
    type: gitea
    cloud_environments:
      - swiss
```

## Parameter Options:

| Field          | Type   | Description                                          |
| -------------- | ------ | ---------------------------------------------------- |
| `service_type` | string | Links this configuration to a service (`services/`). |
| `repositories` | list   | List of repositories per environment and cloud.      |

### `repositories` Options:

| Field                | Type   | Allowed Values         | Description                           |
| -------------------- | ------ | ---------------------- | ------------------------------------- |
| `environment`        | string | `public`, `internal`   | Visibility level of the repository.   |
| `repo`               | string | Git path               | Path to the Git repository.           |
| `type`               | string | `github`, `gitea`      | Type of Git service.                  |
| `cloud_environments` | list   | e.g., `eu_de`, `swiss` | Supported regions for the repository. |
