# 📁 services/

This folder contains metadata files that describe individual cloud services. Each file defines a single service and its configuration across environments.

## 🔧 Example: `ecs.yaml`

```yaml
---
service_category: compute
service_title: Elastic Cloud Server
service_type: ecs
service_uri: elastic-cloud-server
teams:
  - name: docs-compute-rw
    permission: write
cloud_environments:
  - name: eu_de
    visibility: public
  - name: swiss
    visibility: public
is_global: false
```

## Parameter Reference

| Parameter            | Type    | Description                                                           |
| -------------------- | ------- | --------------------------------------------------------------------- |
| `is_global`          | boolean | Indicates whether the service is available globally (`true`/`false`). |
| `service_category`   | string  | Category reference, defined in `service_categories/`.                 |
| `service_title`      | string  | Display name of the service.                                          |
| `service_type`       | string  | Unique identifier used across all metadata.                           |
| `service_uri`        | string  | URI component used in documentation links.                            |
| `cloud_environments` | list    | List of cloud regions and their visibility settings.                  |
| `teams`              | list    | Contributor teams with write or read access.                          |

### `cloud_environments` Options:

| Field        | Type   | Allowed Values                 | Description                         |
| ------------ | ------ | ------------------------------ | ----------------------------------- |
| `name`       | string | e.g., `eu_de`, `swiss`         | Name of the cloud region.           |
| `visibility` | string | `public`, `internal`, `hidden` | Controls visibility of the service. |

### `teams` Options:

| Field        | Type   | Allowed Values  | Description                              |
| ------------ | ------ | --------------- | ---------------------------------------- |
| `name`       | string | team identifier | Name of the team (e.g., `docs-compute-rw`). |
| `permission` | string | `read`, `write` | Access level to the metadata.            |
